@@ -59,21 +59,24 @@ std::string iground(std::string in, int last = 3) {
             Ground::Parameters params;
             params.add("base", {});
             out.beginStep();
-            prg.toGround(out.data, module.logger).ground(params, context, out, true, module.logger);
+            prg.toGround({Sig{"base", 0, false}}, out.data, module.logger).ground(params, context, out, module.logger);
+            out.endStep({});
             out.reset(true);
         }
         for (int i=1; i < last; ++i) {
             Ground::Parameters params;
             params.add("step", {NUM(i)});
             out.beginStep();
-            prg.toGround(out.data, module.logger).ground(params, context, out, true, module.logger);
+            prg.toGround({Sig{"step", 1, false}}, out.data, module.logger).ground(params, context, out, module.logger);
+            out.endStep({});
             out.reset(true);
         }
         {
             Ground::Parameters params;
             params.add("last", {});
             out.beginStep();
-            prg.toGround(out.data, module.logger).ground(params, context, out, true, module.logger);
+            prg.toGround({Sig{"last", 0, false}}, out.data, module.logger).ground(params, context, out, module.logger);
+            out.endStep({});
             out.reset(true);
         }
     }
@@ -153,13 +156,13 @@ TEST_CASE("output-incremental", "[output]") {
             "0\n"
             "1 0 1 2 0 0\n"
             "4 4 r(1) 0\n"
-            "4 4 p(1) 1 -1\n"
             "4 4 q(1) 1 -1\n"
+            "4 4 p(1) 1 -1\n"
             "0\n"
             "1 0 1 3 0 0\n"
             "4 4 r(2) 0\n"
-            "4 4 p(2) 1 -1\n"
             "4 4 q(2) 1 -1\n"
+            "4 4 p(2) 1 -1\n"
             "0\n"
             "4 4 last 1 -1\n"
             "0\n" == iground(
@@ -199,32 +202,32 @@ TEST_CASE("output-incremental", "[output]") {
             "0\n"
             "1 0 1 1 0 0\n"
             "1 1 1 2 0 1 3\n"
-            "1 1 1 3 0 1 4\n"
+            "1 1 1 3 0 0\n"
             "1 1 1 4 0 1 5\n"
-            "1 1 1 5 0 0\n"
-            "1 1 1 6 0 1 7\n"
+            "1 1 1 5 0 1 6\n"
+            "1 1 1 6 0 0\n"
             "1 1 1 7 0 1 8\n"
-            "1 1 1 8 0 0\n"
+            "1 1 1 8 0 1 9\n"
             "1 1 1 9 0 1 10\n"
             "1 1 1 10 0 0\n"
-            "4 4 up=0 1 2\n"
-            "4 4 up=1 2 3 -2\n"
-            "4 4 up=2 2 4 -3\n"
-            "4 4 up=3 2 5 -4\n"
-            "4 4 up=4 1 -5\n"
-            "4 4 lo=1 1 6\n"
-            "4 4 lo=2 2 7 -6\n"
-            "4 4 lo=3 2 8 -7\n"
-            "4 4 lo=4 1 -8\n"
-            "4 4 ib=1 1 9\n"
-            "4 4 ib=2 2 10 -9\n"
-            "4 4 ib=3 1 -10\n"
+            "4 4 ib=1 1 2\n"
+            "4 4 ib=2 2 3 -2\n"
+            "4 4 ib=3 1 -3\n"
+            "4 4 lo=1 1 4\n"
+            "4 4 lo=2 2 5 -4\n"
+            "4 4 lo=3 2 6 -5\n"
+            "4 4 lo=4 1 -6\n"
+            "4 4 up=0 1 7\n"
+            "4 4 up=1 2 8 -7\n"
+            "4 4 up=2 2 9 -8\n"
+            "4 4 up=3 2 10 -9\n"
+            "4 4 up=4 1 -10\n"
             "4 7 step(1) 0\n"
             "0\n"
             "1 0 1 11 0 0\n"
-            "1 0 0 0 1 -5\n"
-            "1 0 0 0 1 6\n"
-            "1 0 0 0 2 -9 10\n"
+            "1 0 0 0 2 -2 3\n"
+            "1 0 0 0 1 4\n"
+            "1 0 0 0 1 -10\n"
             "4 7 step(2) 0\n"
             "0\n"
             "4 6 last=1 0\n"
